import type {
  AffectedRowsResult,
  ForeignKeyRelation,
  MutationOrQueryBaseOptions,
  QueryError,
  QueryResult,
} from '@/types/data-browser';
import normalizeQueryError from '@/utils/dataBrowser/normalizeQueryError';
import { LOCAL_MIGRATIONS_URL } from '@/utils/env';
import prepareTrackForeignKeyRelationsMetadata from './prepareTrackForeignKeyRelationsMetadata';

export interface TrackForeignKeyRelationsMigrationVariables {
  /**
   * Foreign key relation to track.
   */
  foreignKeyRelations: ForeignKeyRelation[];
  /**
   * Schema where the table is located for which the foreign key relation is
   * being tracked.
   */
  schema: string;
  /**
   * Table for which the foreign key relation is being tracked.
   */
  table: string;
}

export interface TrackForeignKeyRelationsMigrationOptions
  extends Omit<MutationOrQueryBaseOptions, 'schema' | 'table'> {}

export default async function trackForeignKeyRelationsMigration({
  dataSource,
  schema,
  table,
  appUrl,
  adminSecret,
  foreignKeyRelations,
}: TrackForeignKeyRelationsMigrationOptions &
  TrackForeignKeyRelationsMigrationVariables) {
  const creatableRelationships = await prepareTrackForeignKeyRelationsMetadata({
    dataSource,
    schema,
    table,
    appUrl,
    adminSecret,
    foreignKeyRelations,
  });

  const response = await fetch(`${LOCAL_MIGRATIONS_URL}/apis/migrate`, {
    method: 'POST',
    headers: {
      'x-hasura-admin-secret': adminSecret,
    },

    body: JSON.stringify({
      dataSource,
      skip_execution: false,
      name: `track_foreign_key_relations_${schema}_${table}`,
      down: [],
      up: creatableRelationships,
    }),
  });

  const responseData: [AffectedRowsResult, QueryResult<string[]>] | QueryError =
    await response.json();

  if (response.ok) {
    return;
  }

  const normalizedError = normalizeQueryError(responseData);

  throw new Error(normalizedError);
}
